@@ -49,6 +49,8 @@
 package com.openexchange.documentconverter.client.impl;
 
 import java.net.URL;
+import java.util.HashSet;
+import java.util.Set;
 import com.openexchange.documentconverter.Config;
 
 /**
@@ -71,12 +73,6 @@ public class ClientConfig implements Config {
      */
     public URL REMOTEURL_DOCUMENTCONVERTER = null;
 
-    /**
-     * Server Base URL to be used for remote ImageServer transformations;
-     * if left empty, no image transformations will be handled
-     */
-    public URL REMOTEURL_IMAGESERVER = null;
-
     /**
      * the maximum size in Bytes for documents to be converted;
      * -1 for no upper limit; default is 128MB
@@ -91,6 +87,13 @@ public class ClientConfig implements Config {
 
     public boolean PREVIEW_ENABLE_CACHE_LOOKUP = true;
 
+    /**
+     * the list of supported extension types
+     * or an empty set, if no extension
+     * check should be performed
+     */
+    public Set<String> SUPPORTED_TYPES = new HashSet<>();
+
     // - Internally used properties --------------------------------------------
 
     /**
