@@ -98,7 +98,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
             boolean queryResultAvailability = false;
 
             if (logTrace) {
-                ClientManager.logTrace("Documentconverter received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
+                ClientManager.logTrace("DC received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
             }
 
             // try to get a valid result from a remotehash request first
@@ -112,7 +112,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
 
                 if (queryResultAvailability) {
                     if (logTrace) {
-                        ClientManager.logTrace("Documentconverter remotehash client query for asynchronous request initiated",
+                        ClientManager.logTrace("DC remotehash client query for asynchronous request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
@@ -120,14 +120,14 @@ public class ManagedClientHashJob extends ManagedClientJob {
                     queryResultAvailability = super.queryAvailability(jobType, hashedJobProperties, resultProperties);
 
                     if (logTrace) {
-                        ClientManager.logTrace("Documentconverter remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
+                        ClientManager.logTrace("DC remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
                             new LogData("exectime", Long.toString(System.currentTimeMillis() - startTime) + "ms"));
                     }
                 } else {
                     if (logTrace) {
-                        ClientManager.logTrace("Documentconverter remotehash client request initiated",
+                        ClientManager.logTrace("DC remotehash client request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
@@ -135,7 +135,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
                     ret = super.process(jobType, hashedJobProperties, resultProperties);
 
                     if (logTrace) {
-                        ClientManager.logTrace("Documentconverter remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
+                        ClientManager.logTrace("DC remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
                             new LogData("exectime", Long.toString(System.currentTimeMillis() - startTime) + "ms"));
