@@ -239,6 +239,7 @@ class ManagedClientJob {
 
     /**
      * @param jobProperties
+     * @param resultProperties
      * @return
      */
     static protected byte[] getInputBuffer(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
@@ -373,7 +374,7 @@ class ManagedClientJob {
                 resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.MAX_SOURCESIZE.errorCode()));
 
                 if (ClientManager.isLogError()) {
-                    ClientManager.logError("Documentconverter detected source file size larger than configured size",
+                    ClientManager.logError("DC detected source file size larger than configured size",
                         jobProperties,
                         new LogData("sourcesize", (new Long(sourceSize)).toString()),
                         new LogData("maxsize", (new Long(maxSize)).toString()));
@@ -402,7 +403,7 @@ class ManagedClientJob {
             }
 
             if (ClientManager.isLogError()) {
-                ClientManager.logError("Documentconverter detected unsupported input file extension",
+                ClientManager.logError("DC detected unsupported input file extension",
                     jobProperties, new LogData("inputype", inputType));
             }
         }
@@ -471,7 +472,7 @@ class ManagedClientJob {
         final String remoteMethod = jobProperties.containsKey(Properties.PROP_REMOTE_METHOD) ? (String) jobProperties.get(Properties.PROP_REMOTE_METHOD) : "";
         final String logTitle = (remoteMethod.equals("transformimage")) ?
             ("ImageServer " + (isAsync ? "asynchronous " : "") + "remote transformation") :
-                ("Documentconverter " + (isAsync ? "asynchronous " : "") + "remote conversion");
+                ("DC " + (isAsync ? "asynchronous " : "") + "remote conversion");
 
             if ((null != m_remoteUrl) && (null != remoteParams)) {
                 final String callCookie = (String) jobProperties.get(Properties.PROP_CONVERTER_COOKIE);
@@ -490,17 +491,24 @@ class ManagedClientJob {
                 if ((null != remoteUrl) && isMultipartRequest) {
                     final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
                     final String inputMimeType = (null != inputType) && (inputType.equals("pdf")) ? "application/pdf" : "application/octet-stream";
-                    final Serializable serialObject = getInputBuffer(jobProperties, resultProperties);
+                    final Serializable contentSerializable =  jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
+                        (File) jobProperties.get(Properties.PROP_INPUT_FILE) :
+                            getInputBuffer(jobProperties, resultProperties);
 
-                    if (null != serialObject) {
+
+                    if (null != contentSerializable) {
                         final TransferObject<Serializable> transferObject = new TransferObject<>(
                             remoteParams,
-                            serialObject,
+                            contentSerializable,
                             "ByteArray.bin",
                             inputMimeType,
                             callCookie);
+                        final TransferHelper.PostFormDataMode postFormDataMode =
+                            ((contentSerializable instanceof File) && (m_clientManager.getRemoteAPIVersion(ServerType.DOCUMENTCONVERTER) >= 6)) ?
+                            TransferHelper.PostFormDataMode.FILE_LENGTH_AND_DATA :
+                                TransferHelper.PostFormDataMode.BYTEARRAY_OBJECT;
 
-                        TransferHelper.postFormData(m_clientManager, remoteUrl, m_serverType, transferObject, new TransferResponseProcessor() {
+                        TransferHelper.postFormData(m_clientManager, remoteUrl, m_serverType, transferObject, postFormDataMode, new TransferResponseProcessor() {
 
                             @SuppressWarnings("unchecked")
                             @Override
@@ -604,7 +612,7 @@ class ManagedClientJob {
                 // fallback conversion or the caller is not interested in the
                 // the current result of these 'try and ignore' conversions
                 if (!isCacheOnly && !isAsync && StringUtils.isEmpty(remoteCacheHash)) {
-                    final StringBuilder errorMessageBuilder = new StringBuilder("Documentconverter received a remote conversion ");
+                    final StringBuilder errorMessageBuilder = new StringBuilder("DC received a remote conversion ");
                     final JobError jobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
 
                     ClientManager.logWarn(errorMessageBuilder.append(
