@@ -204,7 +204,7 @@ class ConvertDocumentAction extends DocumentConverterAction {
             int pageCount = resultProperties.containsKey(Properties.PROP_RESULT_PAGE_COUNT) ? ((Integer) resultProperties.get(Properties.PROP_RESULT_PAGE_COUNT)).intValue() : 0;
 
             if (resultProperties.containsKey(Properties.PROP_RESULT_ERROR_CODE)) {
-                jobError[0] = JobError.fromErrorCode(((Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)).intValue());
+                jobError[0] = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
             }
 
             try {
@@ -302,11 +302,12 @@ class ConvertDocumentAction extends DocumentConverterAction {
                     jobError[0] = JobError.NONE;
                 } catch (Exception e) {
                     logException(e);
-                }
-                finally {
+                } finally {
                     IOUtils.closeQuietly(resultStm);
                 }
             }
+
+            IOUtils.closeQuietly(resultStm);
         }
 
         return fileHolderResult;
