@@ -46,7 +46,6 @@
  *
  */
 
-
 package com.openexchange.documentconverter.client.json;
 
 import java.io.InputStream;
@@ -82,7 +81,6 @@ import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
-
 /**
  * {@link DocumentConverterAction}
  *
@@ -96,7 +94,7 @@ public class DocumentConverterAction implements AJAXActionService {
     // The parameter list is used for the fast detection of ManagedFiles, based on
     // the set of all given attributes to create a unique identifier. The ManagedFile itself
     // is created for the speedup of chunked requests, using the same source again and again
-    final static private String[] idParamArray = { "uid", "id", "folder_id", "version", "revtag", "source", "attached", "module", "cryptoAuth", "attachmentId" };
+    static final private String[] idParamArray = { "uid", "id", "folder_id", "version", "source", "attached", "module", "cryptoAuth" };
 
     /**
      * Initializes a new {@link DocumentConverterAction}.
@@ -141,7 +139,7 @@ public class DocumentConverterAction implements AJAXActionService {
         }
     }
 
-    /**@param documentId
+    /**
      * @param request
      * @param session
      * @param jobError
@@ -186,7 +184,7 @@ public class DocumentConverterAction implements AJAXActionService {
                                 authentication = encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest());
                             }
 
-                            mailServletInterface = MailServletInterface.getInstanceWithDecryptionSupport(session,  authentication);
+                            mailServletInterface = MailServletInterface.getInstanceWithDecryptionSupport(session, authentication);
                         } else {
                             mailServletInterface = MailServletInterface.getInstance(session);
                         }
@@ -226,8 +224,7 @@ public class DocumentConverterAction implements AJAXActionService {
 
                                     fileAccess = encryptionAwareFileAccessFactory.createAccess(fileAccess, cryptMode, session,
                                         encryptionAuthenticationFactory.createAuthenticationFrom(request.optHttpServletRequest()));
-                                }
-                                else {
+                                } else {
                                     // file is encrypted, but we can't decrypt...
                                     fileAccess = null;
                                 }
@@ -244,9 +241,7 @@ public class DocumentConverterAction implements AJAXActionService {
 
                         if (null != fileAccess) {
                             // #46555 map version String("null") to null
-                            String versionToUse = "null".equalsIgnoreCase(version) ?
-                                FileStorageFileAccess.CURRENT_VERSION :
-                                    version;
+                            String versionToUse = "null".equalsIgnoreCase(version) ? FileStorageFileAccess.CURRENT_VERSION : version;
 
                             // #46555 check for versioning support
                             if (FileStorageFileAccess.CURRENT_VERSION != versionToUse) {
@@ -268,7 +263,9 @@ public class DocumentConverterAction implements AJAXActionService {
                     logException(e);
                 } finally {
                     IOUtils.closeQuietly(documentStm);
-                    IOUtils.closeQuietly(mailServletInterface);
+                    if (mailServletInterface != null) {
+                        mailServletInterface.close();
+                    }
                 }
             }
         } finally {
@@ -411,4 +408,3 @@ public class DocumentConverterAction implements AJAXActionService {
 
     protected long m_maxSourceFileSizeMB = 32;
 }
-
