@@ -58,8 +58,6 @@ import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import com.openexchange.ajax.container.FileHolder;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -70,6 +68,7 @@ import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
+import com.openexchange.documentconverter.client.impl.ClientManager;
 import com.openexchange.file.storage.DefaultFile;
 import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageFileAccess;
@@ -200,12 +199,7 @@ public class GetDocumentAction extends DocumentConverterAction {
                                 mimeType = "application/pdf";
                                 managedResultFile = m_managedFileManagement.createManagedFile(resultDocumentId, pdfResultStm);
                             } else {
-                                final Integer errorCode = (Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE);
-                                jobError[0] = isAsync ?
-                                    JobError.NONE :
-                                        ((null != errorCode) ?
-                                            JobError.fromErrorCode(errorCode.intValue()) :
-                                                JobError.GENERAL);
+                                jobError[0] = isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
                             }
                         }
                     }
@@ -243,11 +237,14 @@ public class GetDocumentAction extends DocumentConverterAction {
                     jobProperties.put(Properties.PROP_INFO_FILENAME, fileName);
                 }
 
+                if (isAsync) {
+                    jobProperties.put(Properties.PROP_ASYNC, Boolean.TRUE);
+                }
+
                 // do the PDF encryption test and close possible result stream immediately
                 IOUtils.closeQuietly(docConverter.convert("pdfenctest", jobProperties, resultProperties));
 
-                final Integer errorCode = (Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE);
-                jobError[0] = (null != errorCode) ? JobError.fromErrorCode(errorCode.intValue()) : JobError.GENERAL;
+                jobError[0] = isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
             }
         } else {
             // async case for PDF documents
@@ -268,10 +265,10 @@ public class GetDocumentAction extends DocumentConverterAction {
                     return (new AJAXRequestResult().setHttpStatusCode(ERRORCODE_BAD_REQUEST));
                 }
             } else if (isAsync) {
-                (jsonResult = new JSONObject()).put("async", true);
+                    (jsonResult = new JSONObject()).put("async", true);
             }
         } catch (JSONException e) {
-            logException(e);
+            ClientManager.logExcp(e);
         }
 
         return getRequestResult(request, resultFileHolder, jsonResult, jobError[0]);
@@ -295,12 +292,7 @@ public class GetDocumentAction extends DocumentConverterAction {
             // correct sessionId; set errorcode to 400 in case of an invalid request
             try {
                 if ((null == sessionId) || !sessionId.equals(session.getSessionID())) {
-                    final Logger LOG = LoggerFactory.getLogger(this.getClass());
-
-                    if (null != LOG) {
-                        LOG.error("DC Ajax handler was called with invalid sessionId for save request: " + sessionId);
-                    }
-
+                    ClientManager.logError("DC Ajax handler was called with invalid sessionId for save request: " + sessionId);
                     ret = (new JSONObject()).put(KEY_ERRORCODE, ERRORCODE_BAD_REQUEST);
                 } else {
                     final IDBasedFolderAccessFactory folderFactory = m_services.getService(IDBasedFolderAccessFactory.class);
