@@ -147,7 +147,7 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
             } catch (@SuppressWarnings("unused") final Exception e) {
                 if (log.isErrorEnabled()) {
                     log.error("starting bundle failed: " + m_serviceName);
-                    log.error("Documentconverter manager could not be initialized");
+                    log.error("DC manager could not be initialized");
                 }
             }
         } catch (final Throwable e) {
