@@ -71,6 +71,7 @@ import org.apache.poi.poifs.filesystem.DocumentEntry;
 import org.apache.poi.poifs.filesystem.DocumentInputStream;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
 import org.apache.poi.util.IOUtils;
+import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataProperties;
 import com.openexchange.documentconverter.IDocumentConverter;
@@ -114,6 +115,17 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
         m_serviceLookup = serviceLookup;
     }
 
+    @Override
+    public boolean isSupportedFor(Session session) throws OXException {
+        CapabilityService capabilityService = m_serviceLookup.getOptionalService(CapabilityService.class);
+        if (null == capabilityService) {
+            // Cannot check since service is absent
+            return false;
+        }
+
+        return capabilityService.getCapabilities(session).contains("document_preview");
+    }
+
     /*
      * (non-Javadoc)
      * @see com.openexchange.preview.RemoteInternalPreviewService#getTimeToWaitMillis()
@@ -345,46 +357,51 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
             if (thumbnailPreview) {
                 // try to reuse already existing previews from zipArchive and/or the compound object
-                final PreviewResult fastPreviewResult = getFastPreview(documentFile, fileMimeType);
+                PreviewResult fastPreviewResult = getFastPreview(documentFile, fileMimeType);
 
                 if (null != fastPreviewResult) {
-                    final String fastPreviewMimeType = fastPreviewResult.getPreviewMimeType();
+                    // we have some kind of preview graphics;
+                    // unsupported mimetypes (e.g. emf/pnf/wmf) need to
+                    // be converted to JPEG images using the
+                    // document converter first
+                    if (!supportedTypes.contains(fastPreviewResult.getPreviewMimeType())) {
+                        final String fastPreviewInputType = getInputType(fastPreviewResult.getPreviewMimeType(), null, null);
 
-                    // we get some kind of m_preview graphics -> unsupported mimetypes (emf/wmf) needs to be
-                    // converted using the document converter; other images are just scaled to the proper
-                    // thumbnail destination size (128*90)
-                    if (!supportedTypes.contains(fastPreviewMimeType)) {
-                        final String fastPreviewInputType = getInputType(fastPreviewMimeType, null, null);
-                        final ByteArrayInputStream grfInputStm = new ByteArrayInputStream(fastPreviewResult.getPreviewBuffer());
+                        try (final ByteArrayInputStream grfInputStm = new ByteArrayInputStream(fastPreviewResult.getPreviewBuffer())) {
+                            jobProperties.put(Properties.PROP_INPUT_STREAM, grfInputStm);
+                            jobProperties.put(Properties.PROP_INPUT_TYPE, fastPreviewInputType);
 
-                        jobProperties.put(Properties.PROP_INPUT_STREAM, grfInputStm);
-                        jobProperties.put(Properties.PROP_INPUT_TYPE, fastPreviewInputType);
+                            if (null != fileName) {
+                                jobProperties.put(Properties.PROP_INFO_FILENAME, fileName + ".thumbnail");
+                            }
 
-                        if (null != fileName) {
-                            jobProperties.put(Properties.PROP_INFO_FILENAME, fileName + ".thumbnail");
-                        }
+                            resultProperties.clear();
 
-                        resultProperties.clear();
+                            try (final InputStream grfResultInputStm = docConverter.convert("graphic", jobProperties, resultProperties)) {
+                                if (null != grfResultInputStm) {
+                                    // try to get direct access to the result buffer to avoid an array copy;
+                                    // if result buffer is null, retrieve the result buffer from the result stream
+                                    if (null == (resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER))) {
+                                        resultBuffer = IOUtils.toByteArray(grfResultInputStm);
+                                    }
 
-                        try {
-                            resultInputStm = docConverter.convert("graphic", jobProperties, resultProperties);
-
-                            if (null != resultInputStm) {
-                                // try to get direct access to the result buffer to avoid an array copy;
-                                // if result buffer is null, retrieve the result buffer from the result stream
-                                if (null == (resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER))) {
-                                    resultBuffer = IOUtils.toByteArray(resultInputStm);
+                                    // exchange the existing fast image PreviewResult with
+                                    // the result of the graphic conversion
+                                    if (null != resultBuffer) {
+                                        fastPreviewResult = new PreviewResult(jpegMimeType, resultBuffer);
+                                    }
                                 }
                             }
                         } catch (Exception e) {
                             handleExcp(e);
-                        } finally {
-                            IOUtils.closeQuietly(grfInputStm);
-                            IOUtils.closeQuietly(resultInputStm);
-
-                            resultInputStm = null;
                         }
-                    } else if ((fastPreviewResult.m_mimeType.equals("image/jpeg") || fastPreviewResult.m_mimeType.equals("image/png")) && ((previewWidth > 0) || (previewHeight > 0))) {
+                    }
+
+                    // images with the proper mime tye are finally
+                    // scaled to the proper thumbnail destination size
+                    if ((fastPreviewResult.m_mimeType.equals("image/jpeg") || fastPreviewResult.m_mimeType.equals("image/png")) &&
+                        ((previewWidth > 0) || (previewHeight > 0))) {
+
                         ImageTransformationService imageScalingService = m_serviceLookup.getService(ImageTransformationService.class);
 
                         if (null != imageScalingService) {
@@ -399,7 +416,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                         }
                     }
 
-                    metaData.put("content-type", "image/jpeg");
+                    metaData.put("content-type", jpegMimeType);
                     metaData.put("resourcename", "image.jpg");
 
                     ClientManager.logTrace("OfficePreviewService fulfills thumbnail request from thumbnail contained in document: " + ((null != fileName) ? fileName : ""));
@@ -438,7 +455,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
                 if ((null == resultBuffer) && thumbnailPreview) {
                     // create password protection icon result for thumbnails, if PASSWORD_PROTECTED result flag is set
-                    if (resultProperties.containsKey(Properties.PROP_RESULT_ERROR_CODE) && (JobError.PASSWORD == JobError.fromErrorCode(((Integer) resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)).intValue()))) {
+                    if (JobError.PASSWORD == JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE))) {
                         String resourceName = "pw_text.jpg";
 
                         if (null != fileMimeType) {
@@ -515,7 +532,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                     break;
                 }
             }
-        } catch (IOException e) {
+        } catch (@SuppressWarnings("unused") IOException e) {
             // ok, this may happen with some formats as a try,
             // but shouldn't give any output in the log file
         } finally {
@@ -624,7 +641,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
             try {
                 poifs = new POIFSFileSystem(inputStm);
-            } catch (Exception e) {
+            } catch (@SuppressWarnings("unused") Exception e) {
                 // Fix for bug #32118:
                 // It is valid to suppress error output here, since
                 // we can't ensure that the header is always correctly
@@ -634,38 +651,29 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
             }
 
             if (null != poifs) {
-                final DirectoryEntry dir = poifs.getRoot();
-                DocumentInputStream documentInputStm = null;
-
                 try {
-                    DocumentEntry dsiEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
+                    final DirectoryEntry dir = poifs.getRoot();
+                    final DocumentEntry dsiEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
 
                     if (null != dsiEntry) {
-                        documentInputStm = new DocumentInputStream(dsiEntry);
-                        final byte[] thumbnail = (new SummaryInformation(new PropertySet(documentInputStm))).getThumbnail();
+                        try (final DocumentInputStream documentInputStm = new DocumentInputStream(dsiEntry)) {
+                            final byte[] thumbnail = (new SummaryInformation(new PropertySet(documentInputStm))).getThumbnail();
 
-                        if ((null != thumbnail) && (thumbnail.length > 20) && (3 == thumbnail[8])) {
-                            try (final InputStream thumbnailInputStm = new ByteArrayInputStream(thumbnail, 20, thumbnail.length - 20)) {
-                                final byte[] resultThumbnail = IOUtils.toByteArray(thumbnailInputStm);
+                            if ((null != thumbnail) && (thumbnail.length > 20) && (3 == thumbnail[8])) {
+                                try (final InputStream thumbnailInputStm = new ByteArrayInputStream(thumbnail, 20, thumbnail.length - 20)) {
+                                    final byte[] resultThumbnail = IOUtils.toByteArray(thumbnailInputStm);
 
-                                if (null != resultThumbnail) {
-                                    previewResult = new PreviewResult("image/wmf", resultThumbnail);
+                                    if (null != resultThumbnail) {
+                                        previewResult = new PreviewResult("image/wmf", resultThumbnail);
+                                    }
                                 }
-                            } catch (IOException e) {
-                                // #43582
-                                // it's not critical to silently step over here,
-                                // since we always have a fallback path for thumbnail generation
                             }
                         }
                     }
-                } catch (Exception e) {
+                } catch (@SuppressWarnings("unused") Exception e) {
                     // #42224
                     // it's not critical to silently step over here,
                     // since we always have a fallback path for thumbnail generation
-                } finally {
-                    if (null != documentInputStm) {
-                        documentInputStm.close();
-                    }
                 }
             }
         } catch (IOException e) {
@@ -701,8 +709,6 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
         File ret = null;
 
         if ((null != inputStm) && (null != (ret = ManagerBasics.createTempFile(FileUtils.getTempDirectoryPath(), "oxpreview", null)))) {
-            ret.deleteOnExit();
-
             try {
                 FileUtils.copyInputStreamToFile(inputStm, ret);
             } catch (IOException e) {
@@ -728,11 +734,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
         // explicitly check for input type %PDF-x.x
         if (null != file) {
-            InputStream inputStm = null;
-
-            try {
-                inputStm = FileUtils.openInputStream(file);
-
+            try (final InputStream inputStm = FileUtils.openInputStream(file)) {
                 if (null != inputStm) {
                     final byte[] buffer = new byte[256];
 
@@ -742,8 +744,6 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                 }
             } catch (IOException e) {
                 ClientManager.logExcp(e);
-            } finally {
-                IOUtils.closeQuietly(inputStm);
             }
         }
 
